@@ -402,6 +402,9 @@ unsigned Chain::asUnsigned(bool doStrict) const
     if ( _buf == 0 )
 	return 0;
 
+    // init errno
+    errno = 0;
+    
     long l = strtol(_buf, NULL, 0);
     
     if ( doStrict )
@@ -410,6 +413,11 @@ unsigned Chain::asUnsigned(bool doStrict) const
 	{
 	    Chain msg = Chain("Integer conversion error : ") + Chain(strerror(errno));
 	    throw Exception(EXLOC, msg);	
+	}
+	if ( ( l == LONG_MIN || l == LONG_MAX )  && errno == ERANGE )
+	{
+	    Chain msg = Chain("Out of range : ") + Chain(strerror(errno));
+	    throw Exception(EXLOC, msg);	
 	}	
     }
 
@@ -428,6 +436,9 @@ int Chain::asInteger(bool doStrict) const
     if ( _buf == 0 )
 	return 0;
 
+    // init errno
+    errno = 0;
+
     long l = strtol(_buf, NULL, 0);
     
     if ( doStrict )
@@ -436,7 +447,12 @@ int Chain::asInteger(bool doStrict) const
 	{
 	    Chain msg = Chain("Integer conversion error : ") + Chain(strerror(errno));
 	    throw Exception(EXLOC, msg);	
-	}	
+	}
+	if ( ( l == LONG_MIN || l == LONG_MAX )  && errno == ERANGE )
+	{
+	    Chain msg = Chain("Out of range : ") + Chain(strerror(errno));
+	    throw Exception(EXLOC, msg);	
+	}
     }
 
     if ( l > INT_MAX || l < INT_MIN )
@@ -454,20 +470,25 @@ long Chain::asLong(bool doStrict) const
     if ( _buf == 0 )
 	return 0;	
 
+    // init errno
+    errno = 0;
+
+    long l = strtol(_buf, NULL, 0);
+    
     if ( doStrict )
     {
-	long l = strtol(_buf, NULL, 0);
 	if ( l == 0 && errno == EINVAL )
 	{
 	    Chain msg = Chain("Long conversion error : ") + Chain(strerror(errno));
 	    throw Exception(EXLOC, msg);	
 	}
-	return l;    
-    }
-    else
-    {
-	return strtol(_buf, NULL, 0);
+	if ( ( l == LONG_MIN || l == LONG_MAX )  && errno == ERANGE )
+	{
+	    Chain msg = Chain("Out of range : ") + Chain(strerror(errno));
+	    throw Exception(EXLOC, msg);	
+	}	
     }
+    return l;
 }
 
 unsigned long Chain::asUnsignedLong(bool doStrict) const
@@ -475,20 +496,26 @@ unsigned long Chain::asUnsignedLong(bool doStrict) const
     if ( _buf == 0 )
 	return 0;	
 
+    // init errno
+    errno = 0;
+
+    unsigned long ul = strtoul(_buf, NULL, 0);
+	
     if ( doStrict )
     {
-	unsigned long ul = strtoul(_buf, NULL, 0);
 	if ( ul == 0 && errno == EINVAL )
 	{
 	    Chain msg = Chain("Unsigned long conversion error : ") + Chain(strerror(errno));
 	    throw Exception(EXLOC, msg);	
 	}
-	return ul;	
-    }
-    else
-    {
-	return strtoul(_buf, NULL, 0);
+	if ( ul == ULONG_MAX && errno == ERANGE )
+	{
+	    Chain msg = Chain("Out of range : ") + Chain(strerror(errno));
+	    throw Exception(EXLOC, msg);	
+	}	
+
     }
+    return ul;
 }
 
 long long Chain::asLongLong(bool doStrict ) const
@@ -496,20 +523,26 @@ long long Chain::asLongLong(bool doStrict ) const
     if ( _buf == 0 )
 	return 0;
 
+    // init errno
+    errno = 0;
+    
+    long long ll = strtoll(_buf, NULL, 0);
+    
     if ( doStrict )
     {
-	long long ll = strtoll(_buf, NULL, 0);
 	if ( ll == 0 && errno == EINVAL)
 	{
 	    Chain msg = Chain("Long long conversion error : ") + Chain(strerror(errno));
 	    throw Exception(EXLOC, msg);	
 	}
-	return ll;	
-    }
-    else
-    {
-	return strtoll(_buf, NULL, 0);	
+
+	if ( ( ll == LLONG_MIN || ll == LLONG_MAX )  && errno == ERANGE )
+	{
+	    Chain msg = Chain("Out of range : ") + Chain(strerror(errno));
+	    throw Exception(EXLOC, msg);	
+	}	
     }
+    return ll;
 }
 
 unsigned long long Chain::asUnsignedLongLong(bool doStrict) const
@@ -517,20 +550,26 @@ unsigned long long Chain::asUnsignedLongLong(bool doStrict) const
     if ( _buf == 0 )
 	return 0;	
 
+    // init errno
+    errno = 0;
+
+    unsigned long long ull = strtoull(_buf, NULL, 0);
+    
     if ( doStrict )
     {
-	unsigned long long ull = strtoull(_buf, NULL, 0);
 	if ( ull == 0 && errno == EINVAL)
 	{
 	    Chain msg = Chain("Unsigned long long conversion error : ") + Chain(strerror(errno));
 	    throw Exception(EXLOC, msg);	
 	}
-	return ull;
-    }
-    else
-    {
-	return strtoull(_buf, NULL, 0);
+	if ( ull == ULLONG_MAX && errno == ERANGE )
+	{
+	    Chain msg = Chain("Out of range : ") + Chain(strerror(errno));
+	    throw Exception(EXLOC, msg);	
+	}	
     }
+    return ull;
+   
 }
 
 float Chain::asFloat() const
