@@ -229,7 +229,7 @@ void File::close()
      }
 }
 
-void File::writeByte( char *buf, unsigned long bufsize )
+void File::writeByte( char *buf, unsigned long long bufsize )
 {
      if ( _mode != WRITE && _mode != READWRITE && _mode != APPEND )
      {
@@ -237,7 +237,7 @@ void File::writeByte( char *buf, unsigned long bufsize )
 	 throw Exception(EXLOC, msg);
      }
 
-     unsigned long numbyte = 0;
+     unsigned long long numbyte = 0;
 
      while ( numbyte < bufsize )
      {
@@ -251,7 +251,7 @@ void File::writeByte( char *buf, unsigned long bufsize )
      }
 }
 
-unsigned long File::readByte( char *buf, unsigned long bufsize )
+unsigned long long File::readByte( char *buf, unsigned long long bufsize )
 {
      if ( _mode != READ && _mode != READWRITE )
      {
@@ -259,7 +259,7 @@ unsigned long File::readByte( char *buf, unsigned long bufsize )
 	 throw Exception(EXLOC, msg );
      }
 
-     int numbyte = 0;
+     ssize_t numbyte = 0;
 
      if ( (numbyte = ::read(_fd, buf, bufsize)) == -1 )
      {
@@ -267,7 +267,7 @@ unsigned long File::readByte( char *buf, unsigned long bufsize )
 	 throw Exception(EXLOC, msg);
      }
 
-     return numbyte;
+     return (unsigned long long)numbyte;
 }
 
 void File::writeChain(const Chain& str)
@@ -288,7 +288,7 @@ void File::writeChain(const Chain& str)
      return;
 }
 
-int File::readLine(Chain& line, unsigned long long maxLen)
+unsigned long long File::readLine(Chain& line, unsigned long long maxLen)
 {
     if (_mode != READ && _mode != READWRITE )
     {
@@ -345,8 +345,7 @@ int File::readLine(Chain& line, unsigned long long maxLen)
 }
 
 char File::nextChar()
-{
-    
+{    
     _readPos++;
     
     if ( _readPos >= _readBufLen )
@@ -363,7 +362,7 @@ char File::nextChar()
 
 }
 
-void File::seek(unsigned long pos)
+void File::seek(unsigned long long pos)
 {
     if ( ::lseek(_fd, pos, SEEK_SET) == -1 )
     {
@@ -373,7 +372,7 @@ void File::seek(unsigned long pos)
     return;
 }
 
-void File::trunc(unsigned long size)
+void File::trunc(unsigned long long size)
 {
     if ( ::ftruncate(_fd, size) == -1 )
     {
@@ -400,7 +399,6 @@ void File::rename(const Chain& fileName)
 
 void File::remove()
 {
-
     if ( _mode != CLOSED )
     {
 	throw Exception(EXLOC, "Closed instance is required for remove"); 
@@ -414,7 +412,7 @@ void File::remove()
     return;
 }
 
-int File::Size() const
+unsigned long long File::Size() const
 {
     struct stat sb;
 
@@ -472,7 +470,7 @@ File& File::operator += ( File& f)
     open(APPEND);
     f.open(READ);
         
-    unsigned long numByte;
+    unsigned long long numByte;
     char buffer[READBUFSIZE];
     
     while ((numByte = f.readByte(buffer, READBUFSIZE)) > 0)
@@ -490,6 +488,20 @@ File& File::operator << ( const Chain& str)
     return (*this);
 }
 
+File& File::operator << ( long l)
+{
+    Chain s(l);
+    writeChain(s);
+    return (*this);
+}
+
+File& File::operator << ( long long l)
+{
+    Chain s(l);
+    writeChain(s);
+    return (*this);
+}
+
 File& File::operator << ( unsigned long l)
 {
     Chain s(l);
@@ -497,6 +509,13 @@ File& File::operator << ( unsigned long l)
     return (*this);
 }
 
+File& File::operator << ( unsigned long long l)
+{
+    Chain s(l);
+    writeChain(s);
+    return (*this);
+}
+
 File& File::operator << ( int i)
 {
     Chain s(i);
@@ -504,6 +523,13 @@ File& File::operator << ( int i)
     return (*this);
 }
 
+File& File::operator << ( unsigned u)
+{
+    Chain s(u);
+    writeChain(s);
+    return (*this);
+}
+
 File& File::operator << ( char c)
 {
     char buf[2];
