@@ -38,9 +38,9 @@ public:
     T* First() const;
     T* Next() const;
     
-    int Size() const;
+    unsigned long long Size() const;
     
-    T& operator [] (int i) const;
+    T& operator [] (unsigned long long i) const;
     ListT<T>& operator += (const ListT<T>& s);
     ListT<T>& operator -= (const ListT<T>& s);
     ListT<T>& operator = (const ListT<T>& s);
@@ -264,18 +264,17 @@ template<class T> T* ListT<T>::Next() const
     }
 }
 
-template<class T> int ListT<T>::Size() const
+template<class T> unsigned long long ListT<T>::Size() const
 {
     
     if (_listBase != 0)
     {
-	int size=0;
+	unsigned long long size=0;
 	
 	ListElement* pElement = _listBase;
 	while (pElement)
 	{
 	    size++;
-
 	    pElement = pElement->next;
 	}
 	return (size);
@@ -283,12 +282,12 @@ template<class T> int ListT<T>::Size() const
     return (0);
 }
 
-template<class T> T& ListT<T>::operator [] (int i) const
+template<class T> T& ListT<T>::operator [] (unsigned long long i) const
 {
   
     if (_listBase != 0)
     {
-	int j=0;
+	unsigned long long j=0;
 	ListElement* pElement = _listBase;
 	while (pElement)
 	{
@@ -299,10 +298,8 @@ template<class T> T& ListT<T>::operator [] (int i) const
 	    j++;
 	    pElement = pElement->next;
 	}
-    }
-   
-    throw Exception(EXLOC, "list position exceeded");
-    
+    }   
+    throw Exception(EXLOC, "list position exceeded");    
 }
 
 template<class T> ListT<T>& ListT<T>::operator+=(const ListT<T>& s)
@@ -343,31 +340,26 @@ template<class T> ListT<T>& ListT<T>::operator=(const ListT<T>& s)
 
 template<class T> ListT<T> ListT<T>::operator + (const ListT<T>& s) const
 {
-
     ListT<T> mergeList;
     
     mergeList = *this;
     mergeList += s;
     
-    return mergeList;
-    
+    return mergeList;   
 }
 
 template<class T> ListT<T> ListT<T>::operator - (const ListT<T>& s) const
 {
-
     ListT<T> mergeList;
     
     mergeList = *this;
     mergeList -= s;
     
-    return mergeList;
-    
+    return mergeList;   
 }
 
 template<class T> bool ListT<T>::operator == (const ListT<T>& s) const
 {
-
     if ( _listBase && s._listBase  )
     {
 	ListElement* pElement1 = _listBase;
@@ -384,7 +376,6 @@ template<class T> bool ListT<T>::operator == (const ListT<T>& s) const
 	    {
 		return false;
 	    }
-
 	}
 	if ( pElement1 == 0 && pElement2 == 0)
 	    return true;
