@@ -23,10 +23,6 @@
 #include "Datetime.h"
 #include "Logger.h"
 
-#ifdef HAVE_MINGW
-#define DISABLE_SYSLOG
-#endif
-
 #ifndef DISABLE_SYSLOG
 #include <syslog.h>
 #endif
