@@ -30,23 +30,23 @@ class Net {
 
 public:
     
-    Net(int initMsgBufLen, int sizeBufLen, int maxSendLen);
+    Net(unsigned initMsgBufLen, unsigned sizeBufLen, unsigned maxSendLen);
     ~Net();
     
     NetHandler* connect(const Chain& hostname, const Chain& service);
-    NetHandler* connect(const Chain& hostname, const Chain& service, int timeout);
-    void serve(int port);
-    void serve6(int port);
+    NetHandler* connect(const Chain& hostname, const Chain& service, unsigned timeout);
+    void serve(unsigned port);
+    void serve6(unsigned port);
     void serve(const Chain& hostname, const Chain& service);
     
-    NetHandler* nextRequest(int timeout);
+    NetHandler* nextRequest(unsigned timeout);
     void removeHandle(NetHandler *pN);
     
 private:
 	
-    int _initMsgBufLen;
-    int _sizeBufLen;
-    int _maxSendLen;
+    unsigned _initMsgBufLen;
+    unsigned _sizeBufLen;
+    unsigned _maxSendLen;
    
     int _csock;
 };
