@@ -31,19 +31,19 @@ class Tokenizer {
  public:
     
     Tokenizer(const Chain& tokenStream, const Chain& sep, char esc = '\\');
-    Tokenizer(char* buf, int len, const Chain& sep, char esc = '\\');
+    Tokenizer(char* buf, unsigned long len, const Chain& sep, char esc = '\\');
     ~Tokenizer();
     
     bool nextToken(Chain& token);
     bool getTail(Chain& token);
 
-    void skip(int n);
-    bool rawRead(Chain& token, int n);
+    void skip(unsigned long n);
+    bool rawRead(Chain& token, unsigned long n);
     
-    int numAhead() const;    
+    unsigned long numAhead() const;    
 
     void reset();
-    void reset(char* buf, int len);
+    void reset(char* buf, unsigned long len);
 
     Tokenizer& operator = (const Tokenizer& t);
  
@@ -53,14 +53,14 @@ class Tokenizer {
 
     bool _isLocal;
     char *_streamBuf;
-    int _bufLen;
+    unsigned long _bufLen;
     
     Chain _tokenStream;
     Chain _sep;
     char _esc;
 
-    int _lower;
-    int _upper;
+    unsigned long _lower;
+    unsigned long _upper;
 };
 #endif
 
